#!/bin/bash
PRODUCTNAME="statexplorer"
TMPDIR="/tmp/statexplorer"
INSTALLDIR="/usr/share/ombutel/www"
IPCDIR="/etc/ipconnect"
OLDVERSION=-1
NEWVERSION=-1
MAJORVERSION=3


mkdir -p "$TMPDIR"
mkdir -p "$IPCDIR"

if [ -e "$IPCDIR/$PRODUCTNAME.ver" ]
then
    OLDVERSION=$(cat "$IPCDIR/$PRODUCTNAME.ver" |cut -d"." -f2)
fi
NEWVERSION=$(head -n 1 "$INSTALLDIR/$PRODUCTNAME/version.txt" |cut -d"." -f2)
echo "-- Updating from $MAJORVERSION.$OLDVERSION to $MAJORVERSION.$NEWVERSION"

find "$INSTALLDIR/$PRODUCTNAME/api/scripts" -name '*.sh' -exec dos2unix {} 2> /dev/null \;

if [ ! -f "/etc/$PRODUCTNAME/Settings.php" ]
then
    echo "-- Creating settings"
    cp "$INSTALLDIR/$PRODUCTNAME/api/Settings_template.php" "/etc/$PRODUCTNAME/Settings.php"
fi

chmod +x "$INSTALLDIR/$PRODUCTNAME/InstallScripts/after_remove.sh"
chmod +x "$INSTALLDIR/$PRODUCTNAME/InstallScripts/after_update.sh"
chmod +x "$INSTALLDIR/$PRODUCTNAME/InstallScripts/before_remove.sh"
chmod +x "$INSTALLDIR/$PRODUCTNAME/InstallScripts/before_update.sh"

#On va faire une boucle à partir de "ancienne version + 1" jusqu'a la derniere version incluse
i=$(($OLDVERSION+1))
if [ $OLDVERSION -eq $NEWVERSION ]
then
	i=$OLDVERSION;
	echo "-- Updating same version but different revision, reexecuting patch of $i"
fi

while [ $i -le $NEWVERSION ]
do
    echo "-- Executing patch $MAJORVERSION.$i"
    find "$INSTALLDIR/$PRODUCTNAME/InstallScripts/$MAJORVERSION.$i" -name '*' -exec dos2unix {} 2> /dev/null \;
    bash "$INSTALLDIR/$PRODUCTNAME/InstallScripts/$MAJORVERSION.$i/update.sh"
    i=$(($i+1))
done

if [ -f /tmp/resetdb ]
then
  /bin/sh $INSTALLDIR/$PRODUCTNAME/api/scripts/resetdb.sh
  rm -f /tmp/resetdb
fi


echo "$MAJORVERSION.$NEWVERSION" > "$IPCDIR/$PRODUCTNAME.ver"
echo "-- Update finished"


# #### NE PAS RETIRER CE BLOC DES SCRIPTS DE MISE A JOUR
echo "-- Initializing startup script"
cat > $INSTALLDIR/$PRODUCTNAME/api/scripts/analyse.sh <<-EOF
#!/bin/sh

CURPROCRESET=\`ps -ef | grep resetdb.sh | grep -v grep | awk '{print \$2}'\`
CURPROCIDQUEUE=\`ps -ef | grep queueanalyser.php | grep -v grep | awk '{print \$2}'\`
CURPROCIDCEL=\`ps -ef | grep celanalyser.php | grep -v grep | awk '{print \$2}'\`
if [ -z "\$CURPROCIDQUEUE" -a -z "\$CURPROCIDCEL" -a -z "\$CURPROCRESET" ]
then
  if [ -f /etc/ipconnect/reset_stats ]
  then
    echo "Resetings data after update" >> /var/log/statexplorercron.log
    /bin/bash $INSTALLDIR/$PRODUCTNAME/api/scripts/resetdb.sh
  fi
  nice -n 19 /usr/bin/php $INSTALLDIR/$PRODUCTNAME/api/scripts/queueanalyser/queueanalyser.php &>> /var/log/statexplorercron.log
  nice -n 19 /usr/bin/php $INSTALLDIR/$PRODUCTNAME/api/scripts/celanalyser/celanalyser.php -a -w &>> /var/log/statexplorercron.log
else
  echo "New analyse canceled: script already running." >> /var/log/statexplorercron.log
fi
EOF

cat > /etc/cron.d/statexplorer <<-EOF
PATH=/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/root/bin
* * * * * root /bin/bash $INSTALLDIR/$PRODUCTNAME/api/scripts/analyse.sh &>> /var/log/statexplorercron.log 
EOF
# #### FIN DU BLOC


rm -rf "$TMPDIR"
exit